@@ -1,9 +1,8 @@
 from redis import StrictRedis
 import sys
 
-sys.path.append('../../')
-from inhand.service.SettingService import Redis
-from inhand.service.IHException import ErrorCodeException
+sys.path.append('../')
+from service.SettingService import Redis
 
 class CacheService:
     def __init__(self,settings):
@@ -28,7 +27,6 @@ class CacheService:
     def createCacheService(settings):
         if isinstance(settings,Redis):
             return RedisCacheService(settings)
-        else:
             raise (NameError, "Unsupported cache type: {}".format(database.type))
 
 class RedisCacheService(CacheService):
@@ -39,18 +37,3 @@ class RedisCacheService(CacheService):
                              port=settings.port,
                              db=settings.database,
                              password=settings.password)
-
-    def put(self,key,value,expire=None):
-        if expire is not None:
-            self.cache.setex(key,expire,value)
-        else:
-            self.cache.set(key,value)
-
-    def get(self, key):
-        if self.exists(key):
-            return  self.cache.get(key)
-        else:
-            raise ErrorCodeException(404,"no such key")
-
-    def exists(self, key):
-        return self.cache.exists(key)
\ No newline at end of file
